@@ -47,6 +47,7 @@ UiController::~UiController()
 
 bool UiController::initialize(Core *core)
 {
+    m_errorString.clear();
     QQmlApplicationEngine *engine = new QQmlApplicationEngine(this);
     QQmlContext *rootContext = engine->rootContext();
     rootContext->setContextProperty(QStringLiteral("core"), core);
@@ -60,5 +61,10 @@ bool UiController::initialize(Core *core)
     return true;
 }
 
+QString UiController::errorString() const
+{
+    return m_errorString;
+}
+
 }
 
